import { NavLink } from 'react-router'
import arrowDown from '~/components/icons/arrow-down-dark.svg'
import arrowRight from '~/components/icons/arrow-right-gray.svg'

interface Props {
  name: string
  list: {
    iconUrl: string
    label: string
    url: string
  }[]
}

export default function UserDropdown({ name, list }: Props) {
  return (
    <div className="inline-block relative group">
      <div className="flex items-center gap-2 xl:gap-3 bg-white rounded-full px-3 xl:px-5 py-2 xl:py-2.5 shadow-xl cursor-pointer">
        <span className="leading-none pb-1 font-medium">{name}</span>
        <img src={arrowDown} alt="" width={24} height={24} />
      </div>
      <div className="absolute -right-5 drop-shadow-2xl w-[190px] invisible group-hover:visible">
        <svg
          width="290"
          height="80"
          viewBox="50 32 190 50"
          fill="none"
          xmlns="http://www.w3.org/2000/svg"
          className="w-full"
        >
          <path
            fill-rule="evenodd"
            clip-rule="evenodd"
            d="M70 49C58.9543 49 50 57.9543 50 69L50 69L240 69L240 69C240 57.9543 231.046 49 220 49H178C169.163 49 162.149 40.4683 155.011 35.259C152.203 33.2095 148.743 32 145 32C141.257 32 137.797 33.2095 134.989 35.259C127.851 40.4683 120.837 49 112 49H70Z"
            fill="white"
          />
        </svg>
        <ul className="bg-white -mt-8 px-3 pb-3 rounded-b-2xl space-y-2">
          {list.map((item, i) => (
            <li key={i}>
              <NavLink to={item.url}>
                <div
                  className={
                    'flex items-center gap-2 border-gray-100 pb-2' +
                    (i === list.length - 1 ? '' : ' border-b')
                  }
                >
                  <img src={item.iconUrl} width={24} height={24} alt="" />
                  <span className="leading-none pb-1 font-medium">{item.label}</span>
                  <img className="ml-auto" src={arrowRight} width={24} height={24} alt="" />
                </div>
              </NavLink>
            </li>
          ))}
        </ul>
      </div>
    </div>
  )
}
